[CalendarServer-changes] [79] CalDAVTester/trunk/verifiers/dataMatch.py

source_changes at macosforge.org source_changes at macosforge.org
Wed Aug 30 07:39:57 PDT 2006


Revision: 79
Author:   cdaboo at apple.com
Date:     2006-08-30 07:39:54 -0700 (Wed, 30 Aug 2006)

Log Message:
-----------
Allow data matches with multi-status responses.

Modified Paths:
--------------
    CalDAVTester/trunk/verifiers/dataMatch.py

Modified: CalDAVTester/trunk/verifiers/dataMatch.py
===================================================================
--- CalDAVTester/trunk/verifiers/dataMatch.py	2006-08-30 13:58:13 UTC (rev 78)
+++ CalDAVTester/trunk/verifiers/dataMatch.py	2006-08-30 14:39:54 UTC (rev 79)
@@ -26,8 +26,8 @@
         # Get arguments
         files = args.get("filepath", [])
         
-        # status code must be 200
-        if response.status not in (200,):
+        # status code must be 200, 207
+        if response.status not in (200,207):
             return False, "        HTTP Status Code Wrong: %d" % (response.status,)
         
         # look for response data

-------------- next part --------------
An HTML attachment was scrubbed...
URL: http://lists.macosforge.org/pipermail/calendarserver-changes/attachments/20060830/1f521d21/attachment.html


More information about the calendarserver-changes mailing list